"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FileStoreRepository_1 = require("../FileStoreRepository");
const StepConsoleRepository_1 = require("../StepConsoleRepository");
const StepConsoleRootAggregate_1 = require("../StepConsoleRootAggregate");
const StepServiceRepository_1 = require("../StepServiceRepository");
const StepletConsoleAggregate_1 = require("../StepletConsoleAggregate");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
const TWO = 2;
describe('StepConsoleRootAggregate Tests', () => {
    it('should be defined', () => {
        const stepId = 1;
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(stepId);
        expect(stepConsoleRootAggregate).toBeDefined();
    });
    it('should not perform archival for steplets as steplets are not available', async () => {
        const cleanTemporaryFolderSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'cleanTempFolder')
            .mockResolvedValueOnce();
        const getStepLogsByStepIdSpied = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'getStepLogsByStepId')
            .mockResolvedValueOnce([]);
        const getStepletIdsByStepIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletIdsByStepId')
            .mockResolvedValueOnce([]);
        const archiveSpied = jest.spyOn(StepletConsoleAggregate_1.StepletConsoleAggregate.prototype, 'archive').mockResolvedValueOnce();
        const deleteStepLogsSpied = jest.spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'deleteStepLogs').mockResolvedValueOnce();
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(1);
        await stepConsoleRootAggregate.archive(1);
        expect(cleanTemporaryFolderSpied).toHaveBeenCalledTimes(TWO);
        expect(getStepLogsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(archiveSpied).toHaveBeenCalledTimes(0);
        expect(deleteStepLogsSpied).toHaveBeenCalledTimes(1);
    });
    it('should perform archival when steplets are available', async () => {
        const cleanTemporaryFolderSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'cleanTempFolder')
            .mockResolvedValueOnce();
        const getStepLogsByStepIdSpied = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'getStepLogsByStepId')
            .mockResolvedValueOnce([
            { consoleId: '1', stepId: 1 },
            { consoleId: '1', stepId: 1 }
        ]);
        const getStepletIdsByStepIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletIdsByStepId')
            .mockResolvedValueOnce([1, TWO]);
        const archiveSpied = jest.spyOn(StepletConsoleAggregate_1.StepletConsoleAggregate.prototype, 'archive').mockResolvedValue();
        const deleteStepLogsSpied = jest.spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'deleteStepLogs').mockResolvedValueOnce();
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(1);
        await stepConsoleRootAggregate.archive(1);
        expect(cleanTemporaryFolderSpied).toHaveBeenCalledTimes(TWO);
        expect(getStepLogsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(archiveSpied).toHaveBeenCalledTimes(TWO);
        expect(deleteStepLogsSpied).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=StepConsoleRootAggregate.test.js.map